@@ -30,6 +30,12 @@ import time
 import logging
 import weakref
 
+try:
+    from tap.runner import TAPTestRunner
+except ImportError:
+    print('1..0 # SKIP cannot import TAPTestRunner')
+    raise SystemExit(0)
+
 import dbus
 import _dbus_bindings
 import dbus.glib
@@ -40,8 +46,8 @@ from dbus._compat import is_py2, is_py3
 try:
     from gi.repository import GObject as gobject
 except ImportError:
-    raise SystemExit(77)
-
+    print('1..0 # SKIP cannot import GObject')
+    raise SystemExit(0)
 
 logging.basicConfig()
 
@@ -328,12 +334,12 @@ class TestDBusBindings(unittest.TestCase):
 
     def testAsyncMethods(self):
         print("\n********* Testing asynchronous method implementation *******")
-        for async in (True, False):
+        for async_ in (True, False):
             for fail in (True, False):
                 try:
                     val = ('a', 1, False, [1,2], {1:2})
-                    print("calling AsynchronousMethod with %s %s %s" % (async, fail, val))
-                    ret = self.iface.AsynchronousMethod(async, fail, val)
+                    print("calling AsynchronousMethod with %s %s %s" % (async_, fail, val))
+                    ret = self.iface.AsynchronousMethod(async_, fail, val)
                 except Exception as e:
                     self.assertTrue(fail, '%s: %s' % (e.__class__, e))
                     print("Expected failure: %s: %s" % (e.__class__, e))
@@ -628,4 +634,6 @@ if __name__ == '__main__':
     gobject.threads_init()
     dbus.glib.init_threads()
 
-    unittest.main()
+    runner = TAPTestRunner()
+    runner.set_stream(True)
+    unittest.main(testRunner=runner)
